/**
 * @module lyseproject/ProjectService
 * @extends module:alfresco/core/Core
 * @mixes module:alfresco/core/CoreXhr
 * @author Rasmus Melgaard 
 */
// Define module requirements and callback...
define(["dojo/_base/declare",
        "alfresco/core/Core",
        "alfresco/core/CoreXhr",
        "alfresco/core/NotificationUtils",
        "dojo/request/xhr",
        "dojo/json",
        "dojo/_base/lang",
        "dojo/dom-construct",
        "alfresco/buttons/AlfButton"],
        function(declare, AlfCore, AlfXhr, NotificationUtils, xhr, JSON, lang, domConstruct, AlfButton) {

   return declare([AlfCore, AlfXhr, NotificationUtils], {
      constructor: function(args) {
        this.alfSubscribe("ALF_CREATE_PROJECT", lang.hitch(this, "createProject"));
        this.alfSubscribe("LYSE_EDIT_PROJECT", lang.hitch(this, "editProject"));

        this.alfSubscribe("ALF_CREATE_CONTRACTOR", lang.hitch(this, "createContractor"));
        this.alfSubscribe("LYSE_EDIT_CONTRACTOR", lang.hitch(this, "editContractor"));

        this.alfSubscribe("ALF_CREATE_INTERFACE", lang.hitch(this, "createInterface"));
        this.alfSubscribe("LYSE_EDIT_INTERFACE", lang.hitch(this, "editContractor"));

        this.alfSubscribe("ALF_CREATE_HSE", lang.hitch(this, "createHSE"));
        this.alfSubscribe("LYSE_EDIT_HSE", lang.hitch(this, "editHSE"));

        this.alfSubscribe("ALF_CREATE_MCC", lang.hitch(this, "createMCC"));
        this.alfSubscribe("LYSE_EDIT_MCC", lang.hitch(this, "editMCC"));

        this.alfSubscribe("ALF_CREATE_CIVIL", lang.hitch(this, "createCivil"));
        this.alfSubscribe("LYSE_EDIT_CIVIL", lang.hitch(this, "editCivil"));

        this.alfSubscribe("ALF_CREATE_EPC_ENGINEERING", lang.hitch(this, "createEPCEng"));
        this.alfSubscribe("LYSE_EDIT_EPC_ENGINEERING", lang.hitch(this, "createEPCEng"));

        this.alfSubscribe("ALF_CREATE_PS", lang.hitch(this, "createPS"));
        this.alfSubscribe("LYSE_EDIT_PS", lang.hitch(this, "editPS"));
          /*
          //Ensure the create-project.js javascript is included (Based on create-site.js)
          var _this = this;
           require([Alfresco.constants.URL_RESCONTEXT + "modules/lyse-create-project.js"], function() {
              _this.alfLog("log", "Create Project JavaScript resource loaded");
           });
           require([Alfresco.constants.URL_RESCONTEXT + "components/form/date.js"], function() {
              _this.alfLog("log", "Date resource loaded");
           });
           require([Alfresco.constants.URL_RESCONTEXT + "components/form/date-picker.js"], function() {
              _this.alfLog("log", "Date picker resource loaded");
           });
           require([Alfresco.constants.URL_RESCONTEXT + "components/object-finder/object-finder.js"], function() {
              _this.alfLog("log", "Object finder resource loaded");
           });
          */
      },

      /**
       * This method delegates site creation to the legacy YUI popup.
       *
       * @instance
       * @param {string} site
       */
      createProject: function lyse_ProjectService_createProject(config) {
         // TODO: When an edit site request is received we should display the edit site dialog.
         //       We need to wrap the existing YUI widget in a Dojo object.
         this.alfLog("log", "A request has been made to create a project: ", config);

         // Just use the old YUI popup...
         if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreateProjectInstance === "function")
         {
            Alfresco.module.getCreateProjectInstance().show();
         }
         else
         {
            this.alfLog("error", "Could not find the 'Alfresco.module.getCreateProjectInstance' function - has 'lyse-create-project.js' been included in the page?");
         }
      },
      /**
       * This method delegates site creation to the legacy YUI popup.
       *
       * @instance
       * @param {string} site
       */
      createContractor: function lyse_ProjectService_createContractor(config) {
         // TODO: When an edit site request is received we should display the edit site dialog.
         //       We need to wrap the existing YUI widget in a Dojo object.
         this.alfLog("log", "A request has been made to create a contractor: ", config);

         // Just use the old YUI popup...
         if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreateContractorInstance === "function")
         {
            Alfresco.module.getCreateContractorInstance(config).show();
         }
         else
         {
            this.alfLog("error", "Could not find the 'Alfresco.module.getCreateContractorInstance' function - has 'lyse-create-contractor.js' been included in the page?");
         }
      },
      /**
       * This method delegates site creation to the legacy YUI popup.
       *
       * @instance
       * @param {string} site
       */
      createEPCEng: function lyse_ProjectService_createEpcEng(config) {
         // TODO: When an edit site request is received we should display the edit site dialog.
         //       We need to wrap the existing YUI widget in a Dojo object.
         this.alfLog("log", "A request has been made to create a epc engineering site: ", config);

         // Just use the old YUI popup...
         if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreateEPCEngInstance === "function")
         {
            Alfresco.module.getCreateEPCEngInstance(config).show();
         }
         else
         {
            this.alfLog("error", "Could not find the 'Alfresco.module.getCreateEPCEngInstance' function - has 'lyse-create-epc-eng.js' been included in the page?");
         }
      },


      createInterface: function lyse_ProjectService_createInterface(config) {
          // TODO: When an edit site request is received we should display the edit site dialog.
          //       We need to wrap the existing YUI widget in a Dojo object.
          this.alfLog("log", "A request has been made to create an interface site: ", config);

          // Just use the old YUI popup...
          if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreateInterfaceInstance === "function")
          {
             Alfresco.module.getCreateInterfaceInstance(config).show();
          }
          else
          {
             this.alfLog("error", "Could not find the 'Alfresco.module.getCreateInterfaceInstance' function - has 'lyse-create-interface.js' been included in the page?");
          }
       },

       createHSE: function lyse_ProjectService_createHSE(config) {
           // TODO: When an edit site request is received we should display the edit site dialog.
           //       We need to wrap the existing YUI widget in a Dojo object.
           this.alfLog("log", "A request has been made to create an hse site: ", config);

           // Just use the old YUI popup...
           if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreateHSEInstance === "function")
           {
               Alfresco.module.getCreateHSEInstance(config).show();
           }
           else
           {
               this.alfLog("error", "Could not find the 'Alfresco.module.getCreateHSEInstance' function - has 'lyse-create-hse.js' been included in the page?");
           }
       },
       
       createPS: function lyse_ProjectService_createPS(config) {
           // TODO: When an edit site request is received we should display the edit site dialog.
           //       We need to wrap the existing YUI widget in a Dojo object.
           this.alfLog("log", "A request has been made to create a ps site: ", config);

           // Just use the old YUI popup...
           if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreatePSInstance === "function")
           {
               Alfresco.module.getCreatePSInstance(config).show();
           }
           else
           {
               this.alfLog("error", "Could not find the 'Alfresco.module.getCreatePSInstance' function - has 'lyse-create-ps.js' been included in the page?");
           }
       },
       
       createMCC: function lyse_ProjectService_createMCC(config) {
         this.alfLog("log", "A request has been made to create a MCC site: ", config);

         // Just use the old YUI popup...
         if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreateMCCInstance === "function")
         {
             Alfresco.module.getCreateMCCInstance(config).show();
         }
         else
         {
             this.alfLog("error", "Could not find the 'Alfresco.module.getCreateMCCInstance' function - has 'lyse-create-mcc.js' been included in the page?");
         }
      },
       createCivil: function lyse_ProjectService_createCivil(config) {
           // TODO: When an edit site request is received we should display the edit site dialog.
           //       We need to wrap the existing YUI widget in a Dojo object.
           this.alfLog("log", "A request has been made to create a Civil site: ", config);

           // Just use the old YUI popup...
           if (Alfresco && Alfresco.module && typeof Alfresco.module.getCreateCivilInstance === "function")
           {
               Alfresco.module.getCreateCivilInstance(config).show();
           }
           else
           {
               this.alfLog("error", "Could not find the 'Alfresco.module.getCreateCivilInstance' function - has 'lyse-create-civil.js' been included in the page?");
           }
       },
      /**
       * This method delegates site editing to the legacy YUI popup.
       * 
       * @instance
       * @param {string} site
       */
      editProject: function lyse_ProjectService_editProject(config) {
         // TODO: When an edit site request is received we should display the edit site dialog.
         //       We need to wrap the existing YUI widget in a Dojo object.
         this.alfLog("log", "A request has been made to edit a site: ", config);
         
         // Just use the old YUI popup...
         if (Alfresco && Alfresco.module && typeof Alfresco.module.getEditProjectInstance === "function")
         {
           var test = Alfresco.module.getEditProjectInstance();

           Alfresco.module.getEditProjectInstance().show({
               shortName: config.site
            });
         }
         else
         {
            this.alfLog("error", "Could not find the 'Alfresco.module.getEditProjectInstance' function - has 'edit-project.js' been included in the page?");
         }
      },
      /**
       * This method delegates site editing to the legacy YUI popup.
       * 
       * @instance
       * @param {string} site
       */
      editContractor: function lyse_ProjectService_editContractor(config) {
         // TODO: When an edit site request is received we should display the edit site dialog.
         //       We need to wrap the existing YUI widget in a Dojo object.
         this.alfLog("log", "A request has been made to edit a site: ", config);
         
         // Just use the old YUI popup...
         if (Alfresco && Alfresco.module && typeof Alfresco.module.getEditContractorInstance === "function")
         {
           var test = Alfresco.module.getEditContractorInstance();

           Alfresco.module.getEditContractorInstance().show({
               shortName: config.site
            });
         }
         else
         {
            this.alfLog("error", "Could not find the 'Alfresco.module.getEditContractorInstance' function - has 'edit-contractor.js' been included in the page?");
         }
      },
      editInterface: function lyse_ProjectService_editInterface(config) {
          // TODO: When an edit site request is received we should display the edit site dialog.
          //       We need to wrap the existing YUI widget in a Dojo object.
          this.alfLog("log", "A request has been made to edit a site: ", config);
          
          // Just use the old YUI popup...
          if (Alfresco && Alfresco.module && typeof Alfresco.module.getEditInterfaceInstance === "function")
          {
            var test = Alfresco.module.getEditInterfaceInstance();

            Alfresco.module.getEditInterfaceInstance().show({
                shortName: config.site
             });
          }
          else
          {
             this.alfLog("error", "Could not find the 'Alfresco.module.getEditInterfaceInstance' function - has 'edit-interface.js' been included in the page?");
          }
       },
       editHSE: function lyse_ProjectService_editHSE(config) {
           this.alfLog("log", "A request has been made to edit a site: ", config);

           // Just use the old YUI popup...
           if (Alfresco && Alfresco.module && typeof Alfresco.module.getEditHSEInstance === "function")
           {
               Alfresco.module.getEditHSEInstance().show({
                   shortName: config.site
               });
           }
           else
           {
               this.alfLog("error", "Could not find the 'Alfresco.module.getEditHSEInstance' function - has 'edit-hse.js' been included in the page?");
           }
       },
       editPS: function lyse_ProjectService_editPS(config) {
           this.alfLog("log", "A request has been made to edit a site: ", config);

           // Just use the old YUI popup...
           if (Alfresco && Alfresco.module && typeof Alfresco.module.getEditPSInstance === "function")
           {
               Alfresco.module.getEditPSInstance().show({
                   shortName: config.site
               });
           }
           else
           {
               this.alfLog("error", "Could not find the 'Alfresco.module.getEditPSInstance' function - has 'edit-ps.js' been included in the page?");
           }
       },
       editMCC: function lyse_ProjectService_editMCC(config) {
         this.alfLog("log", "A request has been made to edit a site: ", config);

         // Just use the old YUI popup...
         if (Alfresco && Alfresco.module && typeof Alfresco.module.getEditMCCInstance === "function")
         {
             Alfresco.module.getEditMCCInstance().show({
                 shortName: config.site
             });
         }
         else
         {
             this.alfLog("error", "Could not find the 'Alfresco.module.getEditMCCInstance' function - has 'edit-mcc.js' been included in the page?");
         }
       },
       editCivil: function lyse_ProjectService_editCivil(config) {
           // TODO: When an edit site request is received we should display the edit site dialog.
           //       We need to wrap the existing YUI widget in a Dojo object.
           this.alfLog("log", "A request has been made to edit a site: ", config);

           // Just use the old YUI popup...
           if (Alfresco && Alfresco.module && typeof Alfresco.module.getEditCivilInstance === "function")
           {
               var test = Alfresco.module.getEditCivilInstance();

               Alfresco.module.getEditCivilInstance().show({
                   shortName: config.site
               });
           }
           else
           {
               this.alfLog("error", "Could not find the 'Alfresco.module.getEditCivilInstance' function - has 'lyse-edit-civil.js' been included in the page?");
           }
       }
  });
});